@@ -104,6 +104,16 @@ def test_sys_pipes():
     assert stderr.getvalue() == u"Hi, stdérr\n"
 
 
+def test_sys_pipes_check():
+    # pytest redirects stdout; un-redirect it for the test
+    with mock.patch('sys.stdout', sys.__stdout__), mock.patch(
+        'sys.stderr', sys.__stderr__
+    ):
+        with pytest.raises(ValueError):
+            with sys_pipes():
+                pass
+
+
 def test_redirect_everything():
     stdout = io.StringIO()
     stderr = io.StringIO()
@@ -219,6 +229,9 @@ def test_two_file_pipes(tmpdir):
             assert w.thread is None
             printf("some stdout")
             printf_err("some stderr")
+        # make sure capture stopped
+        printf("after stdout")
+        printf_err("after stderr")
 
     with test_stdout.open() as f:
         assert f.read() == "some stdout\n"
